@@ -302,6 +302,28 @@ ephy_embed_utils_get_title_from_address (const char *address)
   return ephy_string_get_host_name (address);
 }
 
+gboolean
+ephy_embed_utils_urls_have_same_origin (const char *a_url,
+                                        const char *b_url)
+{
+  SoupURI *a_uri, *b_uri;
+  gboolean retval = FALSE;
+
+  a_uri = soup_uri_new (a_url);
+  if (!a_uri)
+    return retval;
+
+  b_uri = soup_uri_new (b_url);
+  if (b_uri) {
+    retval = a_uri->host && b_uri->host && soup_uri_host_equal (a_uri, b_uri);
+    soup_uri_free (b_uri);
+  }
+
+  soup_uri_free (a_uri);
+
+  return retval;
+}
+
 void
 ephy_embed_utils_shutdown (void)
 {
