@@ -94,7 +94,6 @@ set_status (EphyFindToolbar *toolbar,
 	EphyFindToolbarPrivate *priv = toolbar->priv;
 	const char *icon_name = "edit-find-symbolic";
 	const char *tooltip = NULL;
-	gboolean rtl;
 
 	switch (result)
 	{
@@ -107,8 +106,7 @@ set_status (EphyFindToolbar *toolbar,
 
 			break;
 		case EPHY_FIND_RESULT_FOUNDWRAPPED:
-			rtl = gtk_widget_get_direction (GTK_WIDGET (toolbar)) == GTK_TEXT_DIR_RTL;
-			icon_name = rtl ? "view-wrapped-rtl-symbolic" : "view-wrapped-symbolic";
+			icon_name = "view-wrapped-symbolic";
 			tooltip = _("Search wrapped back to the top");
 			break;
 	}
@@ -401,10 +399,7 @@ search_entry_changed_cb (GtkEntry *entry,
         if (str == NULL || *str == '\0') {
                 primary_icon_name = "edit-find-symbolic";
         } else {
-                if (gtk_widget_get_direction (GTK_WIDGET (entry)) == GTK_TEXT_DIR_RTL)
-                        secondary_icon_name = "edit-clear-rtl-symbolic";
-                else
-                        secondary_icon_name = "edit-clear-symbolic";
+                secondary_icon_name = "edit-clear-symbolic";
                 secondary_active = TRUE;
         }
 
