@@ -182,13 +182,13 @@ write_rdf (EphyBookmarks *bookmarks,
 	ret = xmlTextWriterWriteElement 
 		(writer,
 		 (xmlChar *) "title",
-		 (xmlChar *) "Epiphany bookmarks");
+		 (xmlChar *) "Web bookmarks");
 	if (ret < 0) goto out;
 
 	ret = xmlTextWriterWriteElement
 		(writer,
 		 (xmlChar *) "link",
-		 (xmlChar *) "http://www.gnome.org/projects/epiphany/");
+		 (xmlChar *) "https://wiki.gnome.org/Apps/Web");
 	if (ret < 0) goto out;
 
 	ret = xmlTextWriterStartElement (writer, (xmlChar *) "items");
